; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.
;cpu on

[Command]
name = "cpu"
command = ~D,B,F,D,F,DF,B,DF,B,B,U,F, a
time = 1

[Command]
name = "cpu1"
command = ~D,B,F,D,F,DF,B,DF,B,B,F,B, a
time = 1

[Command]
name = "cpu2"
command = ~D,B,F,D,F,DF,B,DF,B,B,F,F, a
time = 1

[Command]
name = "cpu3"
command = ~D,B,F,D,B,DF,B,DF,B,B,U,B, a
time = 1

[Command]
name = "cpu4"
command = ~D,B,F,D,F,DF,B,DF,B,B,U,B, a
time = 1

[Command]
name = "cpu5"
command = ~D,B,F,D,F,DF,B,DF,B,B,D,F, a
time = 1

[Command]
name = "cpu6"
command = ~D,F,F,D,F,DF,B,DF,B,B,D,F, a
time = 1

[Command]
name = "cpu7"
command = ~D,F,F,D,F,DF,U,DF,B,B,D,F, a
time = 1

[Command]
name = "cpu8"
command = ~D,DF,B,BU,U,UF,F,DF,D,F, a
time = 1

[Command]
name = "cpu9"
command = ~D,DF,B,DB,U,UF,F,DF,D,F, a
time = 1

[Command]
name = "cpu10"
command = ~D,B,F,D,F,DF,B,DF,B,B,U,F, b
time = 1

[Command]
name = "cpu11"
command = ~D,B,F,D,F,DF,B,DF,B,B,F,B, b
time = 1

[Command]
name = "cpu12"
command = ~D,B,F,D,F,DF,B,DF,B,B,F,F, b
time = 1

[Command]
name = "cpu13"
command = ~D,B,F,D,B,DF,B,DF,B,B,U,B, b
time = 1

[Command]
name = "cpu14"
command = ~D,B,F,D,F,DF,B,DF,B,B,U,B, b
time = 1

[Command]
name = "cpu15"
command = ~D,B,F,D,F,DF,B,DF,B,B,D,F, b
time = 1

[Command]
name = "cpu16"
command = ~D,F,F,D,F,DF,B,DF,B,B,D,F, b
time = 1

[Command]
name = "cpu17"
command = ~D,F,F,D,F,DF,U,DF,B,B,D,F, b
time = 1

[Command]
name = "cpu18"
command = ~D,DF,B,BU,U,UF,F,DF,D,F, b
time = 1

[Command]
name = "cpu19"
command = ~D,DF,B,DB,U,UF,F,DF,D,F, b
time = 1


[Command]
name = "cpu20"
command = ~D,B,F,D,F,DF,B,DF,B,B,U,F, c
time = 1

[Command]
name = "cpu21"
command = ~D,B,F,D,F,DF,B,DF,B,B,F,B, c
time = 1

[Command]
name = "cpu22"
command = ~D,B,F,D,F,DF,B,DF,B,B,F,F, c
time = 1

[Command]
name = "cpu23"
command = ~D,B,F,D,B,DF,B,DF,B,B,U,B, c
time = 1

[Command]
name = "cpu24"
command = ~D,B,F,D,F,DF,B,DF,B,B,U,B, c
time = 1

[Command]
name = "cpu25"
command = ~D,B,F,D,F,DF,B,DF,B,B,D,F, c
time = 1

[Command]
name = "cpu26"
command = ~D,F,F,D,F,DF,B,DF,B,B,D,F, c
time = 1

[Command]
name = "cpu27"
command = ~D,F,F,D,F,DF,U,DF,B,B,D,F, c
time = 1

[Command]
name = "cpu28"
command = ~D,DF,B,BU,U,UF,F,DF,D,F, c
time = 1

[Command]
name = "cpu29"
command = ~D,DF,B,DB,U,UF,F,DF,D,F, c
time = 1

[Command]
name = "cpu30"
command = ~U,UB,B,UB,U,UF,F,UF,U, a
time = 1

[Command]
name = "cpu31"
command = ~U,UF,F,UF,U,UB,B,UB,U, a
time = 1

[Command]
name = "cpu32"
command = ~U,D,U,D,U,D,U,D,U,D,U, a
time = 1

[Command]
name = "cpu33"
command = ~U,UF,F,DF,D,DB,B,UB,U,UB,B,DB,D,DF,F,UF,U,a
time = 1

[Command]
name = "cpu34"
command = ~U,UB,B,DB,D,DF,F,UF,U,UF,F,DF,D,DB,B,UB,U,a
time = 1

[Command]
name = "cpu35"
command = ~U,UB,B,UB,U,UF,F,UF,U, b
time = 1

[Command]
name = "cpu36"
command = ~U,UF,F,UF,U,UB,B,UB,U, b
time = 1

[Command]
name = "cpu37"
command = ~U,D,U,D,U,D,U,D,U,D,U, b
time = 1

[Command]
name = "cpu38"
command = ~U,UF,F,DF,D,DB,B,UB,U,UB,B,DB,D,DF,F,UF,U,b
time = 1

[Command]
name = "cpu39"
command = ~U,UB,B,DB,D,DF,F,UF,U,UF,F,DF,D,DB,B,UB,U,b
time = 1

[Command]
name = "cpu40"
command = ~U,UB,B,UB,U,UF,F,UF,U, c
time = 1

[Command]
name = "cpu41"
command = ~U,UF,F,UF,U,UB,B,UB,U, c
time = 1

[Command]
name = "cpu42"
command = ~U,D,U,D,U,D,U,D,U,D,U, c
time = 1

[Command]
name = "cpu43"
command = ~U,UF,F,DF,D,DB,B,UB,U,UB,B,DB,D,DF,F,UF,U,c
time = 1

[Command]
name = "cpu44"
command = ~U,UB,B,DB,D,DF,F,UF,U,UF,F,DF,D,DB,B,UB,U,c
time = 1

[Command]
name = "cpu45"
command = ~U,a,a,a,a,a,a,a,a,a,a,a,U,a,a,a,a,a,a,a,a,a,a,a,D,a,a,a,a,a,a,a,a,a,a
time = 1

[Command]
name = "cpu46"
command = ~U,b,b,b,b,b,b,b,b,b,b,b,U,b,b,b,b,b,b,b,b,b,b,b,D,b,b,b,b,b,b,b,b,b,b
time = 1

[Command]
name = "cpu47"
command = ~U,c,c,c,c,c,c,c,c,c,c,c,U,c,c,c,c,c,c,c,c,c,c,c,D,c,c,c,c,c,c,c,c,c,c
time = 1

[Command]
name = "cpu48"
command = ~U,UF,a,a,a,a,a,a,a,a,a,a,a,U,a,a,a,a,a,a,a,a,a,a,a,D,a,a,a,a,a,a,a,a,a,a
time = 1

[Command]
name = "cpu49"
command = ~U,UF,b,b,b,b,b,b,b,b,b,b,b,U,b,b,b,b,b,b,b,b,b,b,b,D,b,b,b,b,b,b,b,b,b,b
time = 1

[Command]
name = "cpu50"
command = ~U,UF,c,c,c,c,c,c,c,c,c,c,c,U,c,c,c,c,c,c,c,c,c,c,c,D,c,c,c,c,c,c,c,c,c,c
time = 1

;-| Super Motions |--------------------------------------------------------

[Command]
name = "sfireball_ab"
command = ~D, DF, F, a+b

;-| Special Motions |------------------------------------------------------
;-----------------
; QCF
[Command]
name = "Fireball_a"
command = ~D, DF, F, a

[Command]
name = "Fireball_b"
command = ~D, DF, F, b

[Command]
name = "QCF_c"
command = ~D, DF, F, c

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

;-----------------
; QCB
[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z

;-----------------
; Uppercut
[Command]
name = "uppercut_a"
command = ~F, D, DF, a

[Command]
name = "uppercut_b"
command = ~F, D, DF, b

[Command]
name = "uppercut_c"
command = ~F, D, DF, c

[Command]
name = "uppercut_x"
command = ~F, D, DF, x

[Command]
name = "uppercut_y"
command = ~F, D, DF, y

[Command]
name = "uppercut_z"
command = ~F, D, DF, z


;--------------------
;Charge_Down_up
[Command]
name = "chargedownup_a"
command = ~60$D, U, a
time = 10

[Command]
name = "chargedownup_b"
command = ~60$D, U, b
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
name = "Shield_a"
command = ~10$B, F, a
time = 30

[Command]
name = "Shield_b"
command = ~10$B, F, b
time = 30

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10



;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "ab"
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1




[State -1,1]
type = ChangeState
value = 200
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = numproj <= 1
trigger1 = statetype = S
trigger1 = ctrl = 1

[State -1,4]
type = ChangeState
value = 600
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1

[State -1,4]
type = ChangeState
value = 610
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1

[State -1,3]
type = ChangeState
value = 210
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1



[State -1]
type = ChangeState
value = 4000
triggerall = command = "c"
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1



[State -1]
type = ChangeState
value = 220
triggerall = command = "x"
triggerall = numproj = 0
triggerall = power >= 500
trigger1 = statetype != A
trigger1 = ctrl = 1


[State -1]
type = ChangeState
value = 230
triggerall = command = "y"
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1

[State -1]
type = ChangeState
value = 630
triggerall = command = "x"
triggerall = numproj = 0
triggerall = power >= 500
trigger1 = statetype = A
trigger1 = ctrl = 1



[State -1]
type = ChangeState
value = 620
triggerall = command = "y"
triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1


[State -1]
type = ChangeState
value = 630
triggerall = var(5) = 1
triggerall = winko != 1
triggerall = statetype = A
triggerall = p2statetype != L
triggerall = numproj = 0
triggerall = power >= 500
triggerall = random < 160
trigger1 = ctrl=1



[State -1]
type = ChangeState
value = 220
triggerall = var(5) = 1
triggerall = winko != 1
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = numproj = 0
triggerall = power >= 500
triggerall = random < 160
trigger1 = ctrl=1

[State -1]
type = ChangeState
value = 620
triggerall = var(5) = 1
triggerall = winko != 1
triggerall = statetype = A
triggerall = p2statetype != L
triggerall = numproj = 0
triggerall = random < 160
trigger1 = ctrl=1

[State -1]
type = ChangeState
value = 230
triggerall = var(5) = 1
triggerall = winko != 1
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = numproj = 0
triggerall = random < 160
trigger1 = ctrl=1


[State -1]
type = ChangeState
value = 610
triggerall = var(5) = 1
triggerall = winko != 1
triggerall = statetype = A
triggerall = p2statetype != L
triggerall = numproj = 0
triggerall = random < 160
trigger1 = ctrl=1

[State -1]
type = ChangeState
value = 210
triggerall = var(5) = 1
triggerall = winko != 1
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = numproj = 0
triggerall = random < 160
trigger1 = ctrl=1